<?php
/**
 * Elementor Widget
 * @package smartwp
 * @since 1.0.0
 */

namespace Elementor;
class smartwp_blog extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'blog-widget';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Blog', 'smartwp' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-sidebar';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'smartwp_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'General Settings', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'enter title text.', 'smartwp' ),
				'default'     => esc_html__('Our Blog','smartwp')
			]
		);

		$this->add_control(
			'sub-title',
			[
				'label'       => esc_html__( 'Sub Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'From banking and insurance to wealth management and on securities distrib ution', 'smartwp' ),
			]
		);	

		$this->end_controls_section();
	}

	/**
	 * Render Elementor widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>	
		<!-- latest	Post Section Start -->
	<section class="latest-post theme-bg p-tb-120" id="blog">
		<div class="container">
			<!-- Section Title -->
			<div class="section-title m-b-60 text-center">
				<h3><?php echo esc_html( $settings['title'] ); ?></h3>
				<p><?php echo wp_kses_post( $settings[ 'sub-title' ] ); ?></p>
			</div>
			<!-- Loop Start -->
			<div class="row">
				<?php  
                   $blog = new \WP_Query(array(  
                   'post_type' =>  'post',  
                   'posts_per_page'  => 3,
                   'ignore_sticky_posts' => 1
                    )  );  
                    if ( $blog->have_posts() ) :
                     while ( $blog->have_posts()) : $blog->the_post(); 
                     $avatar_url = get_avatar_url(get_the_author_meta( 'ID' ), array('size' => 33)); //author avatar image
                ?>
		            <div class="col-lg-4 col-md-6 col-12">
		            	<!-- Single Post -->
		                <div class="single-latest-post">
		                	<?php  if( has_post_thumbnail() ) : ?>
			                    <div class="latest-post-img" > <!-- Post Image -->
			                    	<?php the_post_thumbnail(); ?>
			                    	<a href="<?php the_permalink( ); ?>" class="post-date"><?php the_time( 'd M' ); ?> <br> <?php the_time( 'Y' ); ?></a> <!-- Post Date -->
			                    </div>
		                    <?php endif; ?>
		                    <div class="latest-post-content p-all-30">
		                    	<!-- Meta Information -->
			                    <div class="latest-post-meta p-tb-15">
			                        <ul>
			                            <li class="user">
			                                <a href="<?php the_permalink( ); ?>"><?php echo get_avatar( get_the_author_meta( 'ID' ), 33 ); ?>  <?php echo esc_html__( 'By', 'smartwp' ); ?> <?php the_author(); ?></a>
			                            </li>
			                            <li>
			                                <a href="#"><i class="fas fa-comments"></i><?php comments_popup_link(); ?></a>
			                            </li>
			                        </ul>
			                    </div>
		                        <h4 class="fs-20 lh-30 m-b-30 m-t-15"><a href="<?php the_permalink( ); ?>"><?php the_title(); ?></a></h4>
		                        	<?php the_excerpt(); ?>
		                        <a href="<?php the_permalink( ); ?>" class="border-btn m-t-30"><?php echo esc_html__( 'Read More', 'smartwp' ); ?></a>
		                    </div>
		                </div>
		            </div>
	             <?php endwhile; wp_reset_postdata(); endif; ?>
	        </div>
		</div>
	</section>
	<!-- Latest Post Section End -->
	  
	    <?php 
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new smartwp_blog() );