<?php

/**
 * Elementor widget
 * @package smartwp
 * @since 1.0.0
 * */

namespace Elementor;
class smartwp_brand extends Widget_Base{
	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'brand-widget';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return esc_html__('Brand','smartwp');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-logo';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['smartwp_widgets'];
	}
	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
		protected function _register_controls() {

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'General Settings', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control( 'brand_items', [
			'label'       => esc_html__( 'Brand Item', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => [
				[
					'name'        => 'image',
					'label'       => esc_html__( 'Image', 'smartwp' ),
					'type'        => Controls_Manager::MEDIA,
					'default'     =>
						array(
							'url' => Utils::get_placeholder_image_src(),
						),
					'description' => esc_html__( 'upload image', 'smartwp' )
				],
				array(
					'name'        => 'url',
					'label'       => esc_html__( 'Brand Url', 'smartwp' ),
					'type'        => Controls_Manager::URL,
					'default'     => array(
						'url' => '#'
					),
				),
				
			],

			'title_field' => "{{name}}"
		] );


		$this->add_control(
			'shortcode',
			[
				'label'       => esc_html__( 'Contact Form Shortcode', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'Enter Contact Form Shortcode', 'smartwp' ),

			]
		);


		$this->add_control(
			'contactinfo',
			[
				'label'       => esc_html__( 'Contact Info', 'smartwp' ),
				'type'        => Controls_Manager::WYSIWYG,
				'description' => esc_html__( 'Enter Contact Info', 'smartwp' ),

			]
		);

		$this->end_controls_section();
	}

	protected function render()
	{
		$settings = $this->get_settings_for_display();

		$brand_items = $settings['brand_items'];
		?>
		    	<!-- Contact & Brand Section Start -->
	<section class="contact-section p-t-100 p-b-90" id="contact">
		<div class="container">
			<!-- Brand Carousel Section Start -->
			<div class="brand-carousel p-b-100">
				<div class="brand-carousel-wrap" id="brandActive">
					<?php
			          foreach ( $brand_items as $item ):
			          $image_id = $item['image']['id'];
			          $image_url = wp_get_attachment_image_src( $image_id, 'full', false );
			        ?>
						<div class="single-brand-logo">
							<div class="brand-logo">
								<a href="<?php echo esc_url( $item['url']['url'] ); ?>"><img src="<?php echo esc_url( $image_url[0] ); ?>" alt="logo"></a>
							</div>
						</div>
					<?php endforeach; ?>
				</div>
			</div>
			<!-- Brand Carousel Section End -->
			<div class="row align-items-center">
				<div class="col-lg-4">
					<!-- Contact infomation -->
					<div class="contact-information p-tb-50 p-lr-30">
						<?php echo wp_kses_post( $settings['contactinfo'] ); ?>
					</div>
				</div>
				<div class="col-lg-8">
					<!-- Contact Form  -->
					<div class="contact-form p-all-40">
						 <?php echo do_shortcode( $settings['shortcode'] ); ?>
					</div>
					<!-- End Contact Form -->
				</div>
			</div>
		</div>
	</section>
	<!-- Contact Section End -->
		<?php
	}
}
plugin::instance()->widgets_manager->register_widget_type(new smartwp_brand());