<?php

/**
 * Elementor widget
 * @package smartwp
 * @since 1.0.0
 * */

namespace Elementor;
class smartwp_faq extends Widget_Base{
	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'faq-widget';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return esc_html__('FAQ','smartwp');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-divider';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['smartwp_widgets'];
	}
	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
		protected function _register_controls() {

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'General Settings', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'enter title text.', 'smartwp' ),
				'default'     => esc_html__('Our Expart Faa','smartwp')
			]
		);

		$this->add_control(
			'sub-title',
			[
				'label'       => esc_html__( 'Sub Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'From banking and insurance to wealth management and on securities distrib ution.', 'smartwp' ),
			]
		);	

		$this->add_control( 'faq_left', [
			'label'       => esc_html__( 'Left FAQ LIST', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => [         
				[
					'name'        => 'faqtitle',
					'label'       => esc_html__( 'FAQ Title', 'smartwp' ),
					'type'        => Controls_Manager::TEXTAREA,
					'default'	 => esc_html__( 'What things are covered in support ?', 'smartwp' ),
				],
				[
					'name'        => 'faqcontent',
					'label'       => esc_html__( 'FAQ Content', 'smartwp' ),
					'type'        => Controls_Manager::TEXTAREA,
					'default'	 => esc_html__( 'In brief, we are responsible for the features that, are adviertisfollowing.Solve bugs if there is any bug means if any featur have any question we will answer it.She packed her seven as salia put her initial-scalel-scaletial into the', 'smartwp' ),
				],   

			],
			'title_field' => "{{name}}"
		] );		

		$this->add_control( 'faq_right', [
			'label'       => esc_html__( 'Right FAQ LIST', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => [         
				[
					'name'        => 'faqtitle',
					'label'       => esc_html__( 'FAQ Title', 'smartwp' ),
					'type'        => Controls_Manager::TEXTAREA,
					'default'	 => esc_html__( 'What things are covered in support ?', 'smartwp' ),
				],
				[
					'name'        => 'faqcontent',
					'label'       => esc_html__( 'FAQ Content', 'smartwp' ),
					'type'        => Controls_Manager::TEXTAREA,
					'default'	 => esc_html__( 'In brief, we are responsible for the features that, are adviertisfollowing.Solve bugs if there is any bug means if any featur have any question we will answer it.She packed her seven as salia put her initial-scalel-scaletial into the', 'smartwp' ),
				],   

			],
			'title_field' => "{{name}}"
		] );		


		$this->end_controls_section();
	}

	protected function render()
	{
		$settings = $this->get_settings_for_display();
		?>

			<!-- FAQ start -->
	<section class="faq-section p-tb-120" id="faqs">
		<div class="container">
			<!-- Section Title -->
			<div class="section-title m-b-60 text-center">
				<h3><?php echo esc_html( $settings['title'] ); ?></h3>
				<p><?php echo wp_kses_post( $settings['sub-title'] ); ?></p>
			</div>
			<!-- FAQ Start -->
			<div class="fag-wrapper p-tb-70">
				<div class="row">
					<div class="col-md-10 offset-md-1">
						<div class="faq-wrap accordion clearfix" id="faq">
                            <div class="row">
                                <div class="col-lg-6 col-md-12 col-12">
                                	<?php $i=0; foreach( $settings['faq_left'] as $item ) : ?>
	                                    <div class="card">
	                                        <div class="card-header" id="headingThree<php echo $i; ?>">
	                                            <h6 data-toggle="collapse" data-target="#faqThree<?php echo $i; ?>" aria-expanded="true" aria-controls="faqThree<?php echo $i; ?>">
	                                                <?php echo esc_html( $item['faqtitle'] ); ?>
	                                            </h6>
	                                        </div>

	                                        <div id="faqThree<?php echo $i; ?>" class="collapse <?php echo ( $i==0 ? 'show' : '' ); ?>" aria-labelledby="headingThree<php echo $i; ?>" data-parent="#faq">
	                                            <div class="card-body">
	                                                 <?php echo esc_html( $item['faqcontent'] ); ?>
	                                            </div>
	                                        </div>
	                                    </div>
                                    <?php $i++; endforeach; ?>
                                </div>
                                 <div class="col-lg-6 col-md-12 col-12">
                                 	<?php $i=0; foreach( $settings['faq_right'] as $item ) : ?>
	                                    <div class="card">
	                                        <div class="card-header" id="headingFour<?php echo $i; ?>">
	                                            <h6 data-toggle="collapse" data-target="#faqFour<?php echo $i; ?>" aria-expanded="true" aria-controls="faqFour<?php echo $i; ?>">
	                                                <?php echo esc_html( $item['faqtitle'] ); ?>
	                                            </h6>
	                                        </div>

	                                        <div id="faqFour<?php echo $i; ?>" class="collapse" aria-labelledby="headingFour<?php echo $i; ?>" data-parent="#faq">
	                                            <div class="card-body">
	                                                 <?php echo esc_html( $item['faqcontent'] ); ?>
	                                            </div>
	                                        </div>
	                                    </div>
                                    <?php $i++; endforeach; ?>
                                </div>
                            </div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</section>
	<!-- FAQ END -->

		<?php
	}
}
plugin::instance()->widgets_manager->register_widget_type(new smartwp_faq());