<?php
/**
 * Elementor Widget
 * @package smartwp
 * @since 1.0.0
 */

namespace Elementor;
class smartwp_features extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'smartwp-features';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Features', 'smartwp' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-product-info';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'smartwp_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'features_section_area',
			[
				'label' => esc_html__( 'Features area', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'fheader',
			[
				'label'       => esc_html__( 'Features Header', 'smartwp' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'enter features section header.', 'smartwp' ),
				'default'	  => esc_html__( 'FEATURES', 'smartwp' )
			]
		);		


		$this->add_control( 'features_items', [
			'label'       => esc_html__( 'Features Item', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'default'     => [
				[
					'fname' => esc_html__( 'Technology', 'smartwp' ),
					'fcontent' => esc_html__( 'Website will more new use Pomagamy variation passa', 'smartwp' ),
					'btnText' => esc_html__( 'Read More', 'smartwp' ),
				]
			],
			'fields'      => [

				[
					'name'        => 'fname',
					'label'       => esc_html__( 'Features Name', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
					'description' => esc_html__( 'Enter features Name', 'smartwp' )
				],
				[
					'name'        => 'fcontent',
					'label'       => esc_html__( 'content', 'smartwp' ),
					'type'        => Controls_Manager::TEXTAREA,
				],
				[
					'name'        => 'fiimage',
					'label'       => esc_html__( 'Features Icon Image', 'smartwp' ),
					'type'        => Controls_Manager::MEDIA,
					'default'     =>
						array(
							'url' => Utils::get_placeholder_image_src(),
						),
					'description' => esc_html__( 'upload Icon Image', 'smartwp' )
				],				
				[
					'name'        => 'fbimage',
					'label'       => esc_html__( 'Features Background Image', 'smartwp' ),
					'type'        => Controls_Manager::MEDIA,
					'default'     =>
						array(
							'url' => Utils::get_placeholder_image_src(),
						),
					'description' => esc_html__( 'upload Features  Image', 'smartwp' )
				],
				[
					'name'        => 'btnText',
					'label'       => esc_html__( 'Button Text', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
				],				
				[
					'name'        => 'btnUrl',
					'label'       => esc_html__( 'Button Url', 'smartwp' ),
					'type'        => Controls_Manager::URL,
					'default'	  =>array(
						'url'=>'#'
					)
				],	

			],
			'title_field' => "{{name}}"
		] );


		$this->end_controls_section();

		$this->start_controls_section(
			'about_section_area',
			[
				'label' => esc_html__( 'About area', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'aheader',
			[
				'label'       => esc_html__( 'About Header', 'smartwp' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'enter about section header.', 'smartwp' ),
				'default'	  => esc_html__( 'About US', 'smartwp' )
			]
		);

		$this->add_control(
			'asubheader',
			[
				'label'       => esc_html__( 'About Sub Header', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'enter about section sub header.', 'smartwp' ),
				'default'	  => esc_html__( 'From banking and insurance to wealth management and on securities distrib ution, wededicated financial service them the teams serve all major sectors of the industry.', 'smartwp' )
			]
		);		

		$this->add_control(
			'atitle',
			[
				'label'       => esc_html__( 'About Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'enter about title.', 'smartwp' ),
				'default'	  => esc_html__( 'Our Business Story', 'smartwp' )
			]
		);

		$this->add_control(
			'acontent',
			[
				'label'       => esc_html__( 'About Content', 'smartwp' ),
				'type'        => Controls_Manager::WYSIWYG,
				'description' => esc_html__( 'enter about content.', 'smartwp' ),
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'skill_section_area',
			[
				'label' => esc_html__( 'Skill area', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'sheader',
			[
				'label'       => esc_html__( 'Skill Header', 'smartwp' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'enter Skill section header.', 'smartwp' ),
				'default'	  => esc_html__( 'Our Skills', 'smartwp' )
			]
		);		


		$this->add_control( 'skill_items', [
			'label'       => esc_html__( 'Skill Item', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'default'     => [
				[
					'subject' => esc_html__( 'Graphic Design', 'smartwp' ),
					'number' => esc_html__( '70', 'smartwp' ),
				]
			],
			'fields'      => [

				[
					'name'        => 'subject',
					'label'       => esc_html__( 'SKill Subject', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
					'description' => esc_html__( 'Enter SKill Subject', 'smartwp' )
				],				
				[
					'name'        => 'number',
					'label'       => esc_html__( 'Number', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
				],
				
			],
			'title_field' => "{{name}}"
		] );


		$this->end_controls_section();

	}

	/**
	 * Render Elementor widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$features_items = $settings['features_items'];

		?>	
		<!-- About Section Start -->
    <section class="about-section position-relative p-b-120" id="about">
    	<div class="container">
    		<!-- feature section -->
    		<div class="feature-section">
    			<h2 class="shadow-title"><span class="big-one"><?php echo esc_html( $settings['fheader'] ); ?></span> <span class="small-one"><?php echo esc_html( $settings['fheader'] ); ?></span></h2>
    			<div class="row">
    				<?php foreach( $features_items as $item ) : ?>
    				<div class="col-lg-3 col-md-6 col-12">
    					<!-- Single feature box -->
	    				<div class="single-feature-box p-all-30" style="background-image: url( <?php echo esc_url( $item['fbimage']['url'] ); ?> );">
	    					<div class="feature-img trans-04 m-b-30">
	    						<img src="<?php echo esc_url( $item['fiimage']['url'] ); ?>" alt="icon">
	    					</div>
	    					<div class="feature-content">
	    						<h4 class="fs-22 lh-31 p-b-10 m-b-25"><?php echo esc_html( $item['fname'] ); ?></h4>
    							<p><?php echo esc_html( $item['fcontent'] ); ?></p>
    							<a href="<?php echo esc_url( $item['btnUrl']['url'] ); ?>" class="readmore"><?php echo esc_html( $item['btnText'] ); ?></a>
	    					</div>
	    				</div>
	    			</div>
    				<?php endforeach; ?>
    			</div>
    		</div>
			<!-- feature End -->
			<!-- About Start -->
    		<div class="about-content p-t-120">
    			<!-- Section Title -->
    			<div class="section-title m-b-60 text-center">
    				<h3><?php echo esc_html( $settings['aheader'] ); ?></h3>
    				<p><?php echo wp_kses_post( $settings['asubheader'] ); ?></p>
    			</div>

    			<div class="row align-items-center">
    				<div class="col-lg-6 col-md-6 col-12">
    					<div class="about-text">
    						<h3 class="fs-30 lh-45 m-b-30"><?php echo esc_html( $settings['atitle'] ); ?></span></h3>
    						<?php echo wp_kses_post( $settings['acontent'] ); ?>
    					</div>
    				</div>
    				<div class="col-lg-6 col-md-6 col-12">
    					<!-- Animated Skill bar -->
    					<div class="skillbar-wrap">
    						<h4 class="fs-22 lh-45 m-b-45"><?php echo esc_html( $settings['sheader'] ); ?></h4>
    						<div class="skillbars">
    							<?php foreach( $settings['skill_items'] as $item ) : ?>
    							<!-- Single Skill bar -->
							    <div class="single-bar m-b-20">
									<p class="skill-title lh-45"><?php echo esc_html( $item['subject'] ); ?> <span class="float-r"><?php echo esc_html( $item['number'] ); ?>%</span></p>
									<div class="bar" data-width="<?php echo esc_html( $item['number'] ); ?>%">
										<div class="bar-inner"><div class="bar-icon"><img src="<?php echo get_template_directory_uri(); ?>/img/icon/bar-icon.png" alt="icon"></div></div>
									</div>
							    </div>
								<?php endforeach; ?>
    						</div>
    					</div>
    				</div>
    			</div>
    		</div>
    		<!-- About End -->
    	</div>
    </section>
    <!-- About Section End -->
		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new smartwp_features() );