<?php
/**
 * Elementor Widget
 * @package Smartwp
 * @since 1.0.0
 */

namespace Elementor;
class smartwp_portfolio extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'smartwp-portfolio';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Portfolio', 'smartwp' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-product-info';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'smartwp_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'General Settings', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'enter title text.', 'smartwp' ),
				'default'	  => esc_html__( 'Our Services', 'smartwp' )
			]
		);		


		$this->end_controls_section();
		

		$this->start_controls_section(
			'portfolio_section',
			[
				'label' => esc_html__( 'portfolio Item', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control( 'portfolio_items', [
			'label'       => esc_html__( 'portfolio Item', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'default'     => [
				[
					'title' => esc_html__( 'Global coverage', 'smartwp' ),
					'btnText' => esc_html__( 'Learn More', 'smartwp' ),
				]
			],
			'fields'      => [

				[
					'name'        => 'title',
					'label'       => esc_html__( 'portfolio Name', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
					'description' => esc_html__( 'portfolio Name', 'smartwp' ),
					'default'     => esc_html__( 'Content Marketing', 'smartwp' ),
				],
				[
					'name'        => 'Url',
					'label'       => esc_html__( 'Button Url', 'smartwp' ),
					'type'        => Controls_Manager::URL,
					'default'	  =>array(
						'url'=>'#'
					)
				],
				[
					'name'        => 'displaytag',
					'label'       => esc_html__( 'Display Tags', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
					'description' => esc_html__( 'portfolio Name', 'smartwp' ),
					'default'     => esc_html__( 'DIGITAL PR | SEO', 'smartwp' ),
				],	
				[
					'name'        => 'category',
					'label'       => esc_html__( 'Category', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
					'default'    => esc_html__( 'Uncategory', 'smartwp' ),
				],
				[
					'name'        => 'image',
					'label'       => esc_html__( 'portfolio Icon Image', 'smartwp' ),
					'type'        => Controls_Manager::MEDIA,
					'default'     =>
						array(
							'url' => Utils::get_placeholder_image_src(),
						),
					'description' => esc_html__( 'upload Icon Image', 'smartwp' )
				],				
		

			],
			'title_field' => "{{name}}"
		] );


		$this->end_controls_section();

	}

	/**
	 * Render Elementor widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$portfolio_items = $settings['portfolio_items'];
		?>	
			<!-- Portfolio Section Start -->
		<section class="p-t-120 p-b-90" id="portfolio">
					<div class="container">
				<!-- Section Title -->
				<div class="section-title text-center">
					<h3>Our Services</h3>
				</div>
				<?php 
					$cat = array_column( $portfolio_items, 'category');
					 $cats = array_unique( $cat );
				 ?>
				<!-- Portfolio Filter -->
	            <div class="portfolio-filter text-center">
	                <ul>
	                    <li data-filter="*" class="filter-active">All Project</li>
	                    <?php foreach( $cats as $cat ) : ?>
	                    <li data-filter=".<?php echo esc_attr( strtolower( $cat ) ); ?>"><?php echo esc_html( $cat ); ?></li>
	                   <?php endforeach; ?>
	                </ul>
	            </div>
	            <!-- Portfolio Item -->
	            <div class="row portfolio-items" >
	            	<?php foreach( $portfolio_items as $item ) : ?>
		            	<!-- Single Portfolio -->
		            	<div class="col-lg-6 col-md-6 <?php echo esc_attr( strtolower( $item['category'] ) ); ?>">
		            		<div class="portfolio-item position-relative bg-img-c big-item" style="background-image: url( <?php echo esc_url( $item['image']['url'] ); ?> );">
		            			<div class="view-icon"><a href="<?php echo esc_url( $item['image']['url'] ); ?>"><img src="<?php echo get_template_directory_uri(); ?>/img/icon/eye.png" alt=""></a></div>
		            			<div class="portfolio-content">
		            				<h6 class="fs-16">
		            					<a href="<?php echo esc_url( $item['Url']['url'] ); ?>">
		            						<?php echo esc_html( $item['title'] ); ?>
											<span class="fs-14 fw-700 d-block"><?php echo esc_html( $item['displaytag'] ); ?></span>
		            					</a>
		            				</h6>
		            			</div>
		            		</div>
		            	</div>
		            	<!-- End Portfolio -->
	            	<?php endforeach; ?>
	            </div>
			</div>
		</section>
	<!-- Portfolio Section Start -->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new smartwp_portfolio() );