<?php
/**
 * Elementor Widget
 * @package smartwp
 * @since 1.0.0
 */

namespace Elementor;
class smartwp_banner extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'smartwp-banner-addon';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Slider', 'smartwp' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-product-info';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'smartwp_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {


		$this->start_controls_section(
			'slider_section',
			[
				'label' => esc_html__( 'Slider Item', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control( 'slider_items', [
			'label'       => esc_html__( 'Slider Item', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'default'     => [
				[
					'btnOneText' => esc_html__( 'VIEW MORE', 'smartwp' ),
					'btnTwoText' => esc_html__( 'GET STARTED', 'smartwp' ),
				]
			],
			'fields'      => [

				[
					'name'        => 'title',
					'label'       => esc_html__( 'Slider Header', 'smartwp' ),
					'type'        => Controls_Manager::TEXTAREA,
					'description' => esc_html__( 'Slider Header', 'smartwp' )
				],
				[
					'name'        => 'content',
					'label'       => esc_html__( 'content', 'smartwp' ),
					'type'        => Controls_Manager::WYSIWYG,
				],
				[
					'name'        => 'bgimage',
					'label'       => esc_html__( 'Slider Background Image', 'smartwp' ),
					'type'        => Controls_Manager::MEDIA,
					'default'     =>
						array(
							'url' => Utils::get_placeholder_image_src(),
						),
					'description' => esc_html__( 'upload Background Image', 'smartwp' )
				],				
				[
					'name'        => 'image',
					'label'       => esc_html__( 'Slider Image', 'smartwp' ),
					'type'        => Controls_Manager::MEDIA,
					'default'     =>
						array(
							'url' => Utils::get_placeholder_image_src(),
						),
					'description' => esc_html__( 'upload Image', 'smartwp' )
				],
				[
					'name'        => 'btnOneText',
					'label'       => esc_html__( 'Button One Text', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
				],				
				[
					'name'        => 'btnOneUrl',
					'label'       => esc_html__( 'Button One Url', 'smartwp' ),
					'type'        => Controls_Manager::URL,
					'default'	  =>array(
						'url'=>'#'
					)
				],				
				[
					'name'        => 'btnTwoText',
					'label'       => esc_html__( 'Button Two Text', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
				],				
				[
					'name'        => 'btnTwoUrl',
					'label'       => esc_html__( 'Button Two Url', 'smartwp' ),
					'type'        => Controls_Manager::URL,
					'default'	  =>array(
						'url'=>'#'
					)
				],

			],
			'title_field' => "{{name}}"
		] );


		$this->end_controls_section();

	}

	/**
	 * Render Elementor widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$slider_items = $settings['slider_items'];
		?>	
		<!-- Hero Slider Section -->
	    <section class="hero-banner" id="heroSlideActive">
	    	<?php foreach( $slider_items as $item ) : ?>
		    	<div class="single-banner-wrap">
		    		<div class="single-banner" style="background-image: url( <?php echo esc_url( $item['bgimage']['url'] ); ?> );">
		    			<div class="container">
		    				<div class="row align-items-center">
		    					<div class="col-lg-7">
		    						<div class="banner-text fs-16 lh-28">
		    							<h1 class="fs-45 lh-60 m-b-45" data-animation="fadeInUp" data-delay=".4s">
		    								<?php echo wp_kses_post( $item['title'] ); ?>
		    							</h1>
		    							 <?php echo wp_kses_post( $item['content'] ); ?>
		    							<div class="slider-btns m-t-65">
		    								<a href="<?php echo esc_url( $item['btnOneUrl']['url'] ); ?>" class="boxed-btn m-r-30" data-animation="fadeInUp" data-delay=".8s"><?php echo esc_html( $item['btnOneText'] ); ?></a>
		    								<a href="<?php echo esc_url( $item['btnTwoUrl']['url'] ); ?>" class="boxed-btn boxed-btn-white" data-animation="fadeInUp" data-delay=".8s" ><?php echo esc_html( $item['btnTwoText'] ); ?></a>
		    							</div>
		    						</div>
		    					</div>
		    					<div class="banner-img">
		    						<img src="<?php echo esc_url( $item['image']['url'] ); ?>" alt="image">
		    					</div>
		    				</div>
		    			</div>
		    		</div>
	    	</div>
	    	<?php endforeach; ?>
	    </section>
	    <!-- Hero Slider Section End-->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new smartwp_banner() );