<?php

/**
 * Elementor widget
 * @package smartwp
 * @since 1.0.0
 * */

namespace Elementor;
class smartwp_team extends Widget_Base{
	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'team-widget';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return esc_html__('Team','smartwp');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-divider';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['smartwp_widgets'];
	}
	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
		protected function _register_controls() {

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'General Settings', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'enter title text.', 'smartwp' ),
				'default'     => esc_html__('Our Expart Team','smartwp')
			]
		);

		$this->add_control(
			'sub-title',
			[
				'label'       => esc_html__( 'Sub Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'From banking and insurance to wealth management and on securities distrib ution.', 'smartwp' ),
			]
		);	

		$this->add_control( 'team_member_items_top', [
			'label'       => esc_html__( 'Team Members Top Column List', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => [         
				[
					'name'        => 'imagetop',
					'label'       => esc_html__( 'Team Member Image', 'smartwp' ),
					'type'        => Controls_Manager::MEDIA,
					'default'     =>
						array(
							'url' => Utils::get_placeholder_image_src(),
						),
					'description' => esc_html__( 'upload image', 'smartwp' )
				],
				[
					'name'        => 'contenttop',
					'label'       => esc_html__( 'Team Member Content', 'smartwp' ),
					'type'        => Controls_Manager::WYSIWYG,
				],   

			],
			'title_field' => "{{name}}"
		] );		

		$this->add_control( 'team_member_items_bottom', [
			'label'       => esc_html__( 'Team Members Bottom Column List', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => [         
				[
					'name'        => 'imagetop',
					'label'       => esc_html__( 'Team Member Image', 'smartwp' ),
					'type'        => Controls_Manager::MEDIA,
					'default'     =>
						array(
							'url' => Utils::get_placeholder_image_src(),
						),
					'description' => esc_html__( 'upload image', 'smartwp' )
				],
				[
					'name'        => 'contentbottom',
					'label'       => esc_html__( 'Team Member Content', 'smartwp' ),
					'type'        => Controls_Manager::WYSIWYG,
				],   

			],
			'title_field' => "{{name}}"
		] );


		$this->end_controls_section();
	}

	protected function render()
	{
		$settings = $this->get_settings_for_display();

		?>

		<!-- Exclusive Services End -->
    <section class="team-section theme-bg p-tb-120" id="team">
        <div class="container">
            <!-- Section Title -->
            <div class="section-title m-b-60 text-center">
                <h3><?php echo esc_html( $settings['title'] ); ?></h3>
                <p><?php echo wp_kses_post( $settings['sub-title'] ); ?></p>
            </div>
            <!-- Our Expart Team -->
            <div class="team-wrapper">
                <div class="row justify-content-center margin-bottom-row">
                	<?php foreach( $settings[ 'team_member_items_top' ] as $item ): ?>
	                    <div class="col-lg-3 col-md-6">
	                        <!-- Single Team -->
	                        <div class="single-team team-one">
	                            <img src="<?php echo esc_url( $item['imagetop'][ 'url' ] ); ?>" alt="team member image">
	                            <div class="team-hover text-center">
	                                <?php echo wp_kses_post( $item['contenttop'] ); ?>
	                            </div>
	                        </div>
	                    </div>
	                 <?php endforeach; ?>
                </div>
                <div class="row">
                	<?php foreach( $settings['team_member_items_bottom'] as $item ): ?>
	                    <div class="col-lg-3 col-md-6">
	                        <div class="single-team team-four">
	                            <!-- Single Team -->
	                            <img src="<?php echo esc_url( $item['imagetop'][ 'url' ] ); ?>" alt="member image">
	                            <div class="team-hover text-center">
	                                <?php echo wp_kses_post( $item['contentbottom'] ); ?>
	                            </div>
	                        </div>
	                    </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>
    </section>
    <!-- Team Section End -->

		<?php
	}
}
plugin::instance()->widgets_manager->register_widget_type(new smartwp_team());